==> uclean-permission-plugin-0.0.1.tgz: package/android/src/main/java/com/ujing/plugin/permission/UcleanPermissionPlugin.java <==
package com.ujing.plugin.permission;

import android.Manifest;
import android.bluetooth.BluetoothAdapter;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.provider.Settings;
import android.text.TextUtils;

import com.getcapacitor.JSArray;
import com.getcapacitor.JSObject;
import com.getcapacitor.NativePlugin;
import com.getcapacitor.Plugin;
import com.getcapacitor.PluginCall;
import com.getcapacitor.PluginMethod;

import org.json.JSONException;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@NativePlugin
public class UcleanPermissionPlugin extends Plugin {

    @PluginMethod
    public void echo(PluginCall call) {
        String value = call.getString("value");

        JSObject ret = new JSObject();
        ret.put("value", value);
        call.success(ret);
    }

    @PluginMethod
    public void checkSelfPermissions(PluginCall call) {
        JSArray jsArray = call.getArray("permissions");
        if (jsArray == null || jsArray.length() == 0){
            JSObject ret = new JSObject();
            ret.put("errorCode","-1");
            ret.put("errorMessage","permissions 数组不能为空");

            call.success(ret);
            return;
        }
        List<String> permissionList = new ArrayList<>();
        for (int i = 0; i < jsArray.length(); i++){
            try {
                permissionList.add(jsArray.getString(i));
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        String[] PERMISSIONS = null;
        List<Map<String, Object>> resultList = new ArrayList<>();
        for (String string : permissionList){
            Map<String, Object> resultMap = new HashMap<>();
            switch (string){
                case "bluetoothle":
                    //蓝牙权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.BLUETOOTH,
                            Manifest.permission.BLUETOOTH_ADMIN};
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS));
                    break;
                case "bluetoothleOpen":
                    //蓝牙开关
                    BluetoothAdapter blueAdapter = BluetoothAdapter.getDefaultAdapter();
                    if (blueAdapter != null) {
                        resultMap.put(string, blueAdapter.isEnabled());
                    } else {
                        resultMap.put(string, false);
                    }
                    break;
                case "camera":
                    //相机权限
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.CAMERA));
                    break;
                case "location":
                    //定位权限
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.ACCESS_FINE_LOCATION));
                    break;
                case "locationService":
                    //位置信息开关
                    resultMap.put(string, isLocationEnabled(getContext().getApplicationContext()));
                    break;
                case "storage":
                    //存储权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.READ_EXTERNAL_STORAGE,
                            Manifest.permission.WRITE_EXTERNAL_STORAGE};
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS));
                    break;
            }
            resultList.add(resultMap);
        }

        JSObject ret = new JSObject();
        ret.put("errorCode","0");
        ret.put("errorMessage","");
        ret.put("data",resultList);

        call.success(ret);
    }

    @PluginMethod
    public void setPermissions(PluginCall call) {
        JSArray jsArray = call.getArray("permissions");
        if (jsArray == null || jsArray.length() == 0){
            JSObject ret = new JSObject();
            ret.put("errorCode","-1");
            ret.put("errorMessage","permissions 数组不能为空");

            call.success(ret);
            return;
        }
        List<String> permissionList = new ArrayList<>();
        String[] PERMISSIONS = null;

        for (int i = 0; i < jsArray.length(); i++){
            try {
                permissionList.add(jsArray.getString(i));
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }

        for (String string : permissionList) {
            switch (string) {
                case "bluetoothle":
                    //蓝牙权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.BLUETOOTH,
                            Manifest.permission.BLUETOOTH_ADMIN};
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS)) {
                        PermissionsActivity.startActivityForResult(getActivity(), PERMISSIONS);
                    }
                    break;
                case "bluetoothleOpen":
                    //蓝牙开关
                    BluetoothAdapter blueAdapter = BluetoothAdapter.getDefaultAdapter();
                    if (blueAdapter != null) {
                        if (!blueAdapter.isEnabled()) {
                            Intent enableBtIntent = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
                            getActivity().startActivityForResult(enableBtIntent, 0);
                        }
                    }
                    break;
                case "camera":
                    //相机权限
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.CAMERA)) {
                        PermissionsActivity.startActivityForResult(getActivity(), Manifest.permission.CAMERA);
                    }
                    break;
                case "location":
                    //定位权限
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.ACCESS_FINE_LOCATION)) {
                        PermissionsActivity.startActivityForResult(getActivity(), Manifest.permission.ACCESS_FINE_LOCATION);
                    }
                    break;
                case "locationService":
                    //位置信息开关
                    if (!isLocationEnabled(getContext())) {
                        Intent intent = new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS);
                        getActivity().startActivityForResult(intent, 0);
                    }
                    break;
                case "storage":
                    //存储权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.READ_EXTERNAL_STORAGE,
                            Manifest.permission.WRITE_EXTERNAL_STORAGE};
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS)) {
                        PermissionsActivity.startActivityForResult(getActivity(), PERMISSIONS);
                    }
                    break;
            }
        }

        JSObject ret = new JSObject();
        ret.put("errorCode", "0");
        ret.put("errorMessage", "");

        call.success(ret);
    }

    @PluginMethod
    public void jumpToSystemSetting(PluginCall call) {
        String permission = call.getString("permission","appDetail");
        switch (permission){
            case "appDetail":
                Intent intent = new Intent();
                intent.setAction("android.settings.APPLICATION_DETAILS_SETTINGS");
                intent.setData(Uri.parse("package:" + "com.midea.vm.washer"));
                getActivity().startActivity(intent);
                break;
        }

        JSObject ret = new JSObject();
        ret.put("errorCode", "0");
        ret.put("errorMessage", "");

        call.success(ret);
    }


    /**
     * 位置服务是否打开
     *
     * @param context
     * @return
     */
    public boolean isLocationEnabled(Context context) {
        int locationMode = 0;
        String locationProviders;

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            try {
                locationMode = Settings.Secure.getInt(context.getContentResolver(), Settings.Secure.LOCATION_MODE);

            } catch (Settings.SettingNotFoundException e) {
                e.printStackTrace();
                return false;
            }

            return locationMode != Settings.Secure.LOCATION_MODE_OFF;

        } else {
            locationProviders = Settings.Secure.getString(context.getContentResolver(), Settings.Secure.LOCATION_PROVIDERS_ALLOWED);
            return !TextUtils.isEmpty(locationProviders);
        }
    }


}

==> uclean-permission-plugin-0.0.3.tgz: package/android/src/main/java/com/ujing/plugin/permission/UcleanPermissionPlugin.java <==
package com.ujing.plugin.permission;

import android.Manifest;
import android.bluetooth.BluetoothAdapter;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.provider.Settings;
import android.text.TextUtils;

import com.getcapacitor.JSArray;
import com.getcapacitor.JSObject;
import com.getcapacitor.NativePlugin;
import com.getcapacitor.Plugin;
import com.getcapacitor.PluginCall;
import com.getcapacitor.PluginMethod;

import org.json.JSONArray;
import org.json.JSONException;

import java.util.ArrayList;
import java.util.List;

@NativePlugin
public class UcleanPermissionPlugin extends Plugin {

    @PluginMethod
    public void echo(PluginCall call) {
        String value = call.getString("value");

        JSObject ret = new JSObject();
        ret.put("value", value);
        call.success(ret);
    }

    @PluginMethod
    public void checkSelfPermissions(PluginCall call) {
        JSArray jsArray = call.getArray("permissions");
        if (jsArray == null || jsArray.length() == 0){
            JSObject ret = new JSObject();
            ret.put("errorCode","-1");
            ret.put("errorMessage","permissions 数组不能为空");

            call.success(ret);
            return;
        }
        List<String> permissionList = new ArrayList<>();
        for (int i = 0; i < jsArray.length(); i++){
            try {
                permissionList.add(jsArray.getString(i));
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        String[] PERMISSIONS = null;
        List<JSObject> resultList = new ArrayList<>();
        for (String string : permissionList){
            JSObject resultMap = new JSObject();
            switch (string){
                case "bluetoothle":
                    //蓝牙权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.BLUETOOTH,
                            Manifest.permission.BLUETOOTH_ADMIN};
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS));
                    break;
                case "bluetoothleOpen":
                    //蓝牙开关
                    BluetoothAdapter blueAdapter = BluetoothAdapter.getDefaultAdapter();
                    if (blueAdapter != null) {
                        resultMap.put(string, blueAdapter.isEnabled());
                    } else {
                        resultMap.put(string, false);
                    }
                    break;
                case "camera":
                    //相机权限
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.CAMERA));
                    break;
                case "location":
                    //定位权限
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.ACCESS_FINE_LOCATION));
                    break;
                case "locationService":
                    //位置信息开关
                    resultMap.put(string, isLocationEnabled(getContext().getApplicationContext()));
                    break;
                case "storage":
                    //存储权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.READ_EXTERNAL_STORAGE,
                            Manifest.permission.WRITE_EXTERNAL_STORAGE};
                    resultMap.put(string, !PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS));
                    break;
            }
            resultList.add(resultMap);
        }
        JSONArray jsonArray = new JSONArray(resultList);


        JSObject ret = new JSObject();
        ret.put("errorCode","0");
        ret.put("errorMessage","");
        ret.put("data",jsonArray);

        call.success(ret);
    }

    @PluginMethod
    public void setPermissions(PluginCall call) {
        JSArray jsArray = call.getArray("permissions");
        if (jsArray == null || jsArray.length() == 0){
            JSObject ret = new JSObject();
            ret.put("errorCode","-1");
            ret.put("errorMessage","permissions 数组不能为空");

            call.success(ret);
            return;
        }
        List<String> permissionList = new ArrayList<>();
        String[] PERMISSIONS = null;

        for (int i = 0; i < jsArray.length(); i++){
            try {
                permissionList.add(jsArray.getString(i));
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }

        for (String string : permissionList) {
            switch (string) {
                case "bluetoothle":
                    //蓝牙权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.BLUETOOTH,
                            Manifest.permission.BLUETOOTH_ADMIN};
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS)) {
                        PermissionsActivity.startActivityForResult(getActivity(), PERMISSIONS);
                    }
                    break;
                case "bluetoothleOpen":
                    //蓝牙开关
                    BluetoothAdapter blueAdapter = BluetoothAdapter.getDefaultAdapter();
                    if (blueAdapter != null) {
                        if (!blueAdapter.isEnabled()) {
                            Intent enableBtIntent = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
                            getActivity().startActivityForResult(enableBtIntent, 0);
                        }
                    }
                    break;
                case "camera":
                    //相机权限
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.CAMERA)) {
                        PermissionsActivity.startActivityForResult(getActivity(), Manifest.permission.CAMERA);
                    }
                    break;
                case "location":
                    //定位权限
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermission(Manifest.permission.ACCESS_FINE_LOCATION)) {
                        PermissionsActivity.startActivityForResult(getActivity(), Manifest.permission.ACCESS_FINE_LOCATION);
                    }
                    break;
                case "locationService":
                    //位置信息开关
                    if (!isLocationEnabled(getContext())) {
                        Intent intent = new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS);
                        getActivity().startActivityForResult(intent, 0);
                    }
                    break;
                case "storage":
                    //存储权限
                    PERMISSIONS = new String[]{
                            Manifest.permission.READ_EXTERNAL_STORAGE,
                            Manifest.permission.WRITE_EXTERNAL_STORAGE};
                    if (PermissionUtils.getInstance(getContext().getApplicationContext()).lacksPermissions(PERMISSIONS)) {
                        PermissionsActivity.startActivityForResult(getActivity(), PERMISSIONS);
                    }
                    break;
            }
        }

        JSObject ret = new JSObject();
        ret.put("errorCode", "0");
        ret.put("errorMessage", "");

        call.success(ret);
    }

    @PluginMethod
    public void jumpToSystemSetting(PluginCall call) {
        String permission = call.getString("permission","appDetail");
        switch (permission){
            case "appDetail":
                Intent intent = new Intent();
                intent.setAction("android.settings.APPLICATION_DETAILS_SETTINGS");
                intent.setData(Uri.parse("package:" + "com.midea.vm.washer"));
                getActivity().startActivity(intent);
                break;
        }

        JSObject ret = new JSObject();
        ret.put("errorCode", "0");
        ret.put("errorMessage", "");

        call.success(ret);
    }


    /**
     * 位置服务是否打开
     *
     * @param context
     * @return
     */
    public boolean isLocationEnabled(Context context) {
        int locationMode = 0;
        String locationProviders;

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            try {
                locationMode = Settings.Secure.getInt(context.getContentResolver(), Settings.Secure.LOCATION_MODE);

            } catch (Settings.SettingNotFoundException e) {
                e.printStackTrace();
                return false;
            }

            return locationMode != Settings.Secure.LOCATION_MODE_OFF;

        } else {
            locationProviders = Settings.Secure.getString(context.getContentResolver(), Settings.Secure.LOCATION_PROVIDERS_ALLOWED);
            return !TextUtils.isEmpty(locationProviders);
        }
    }


}
